@@ -1,20 +1,14 @@
 use warnings;
 use strict;
-package Test::Module 0.003; # TRIAL
+package Test::Module 0.20180802; # TRIAL
 
-# ABSTRACT: This is an example module
+# ABSTRACT: brief summary of what this module is used for
 
 use Exporter 'import';
 our (@EXPORT_OK) = ();
 our (@EXPORT)    = (@EXPORT_OK);
 
 
-
-sub new {
-    my $pkg = shift;
-    bless {}, $pkg;
-}
-
 1;
 
 __END__
@@ -25,24 +19,17 @@ __END__
 
 =head1 NAME
 
-Test::Module - This is an example module
+Test::Module - brief summary of what this module is used for
 
 =head1 VERSION
 
-version 0.003
+version 0.20180802
 
 =head1 SYNOPSIS
 
     use Test::Module;
 
-    my $obj = new Test::Module;
-    print "Hello World\n" if $obj->isa('Test::Module');
-
-=head1 METHODS
-
-=head2 new
-
-Takes no arguments and returns a blessed reference.
+    ## ... code that uses your package
 
 =head1 AUTHOR
 
